@@ -1,14 +1,13 @@
 package Net::Stomp::Producer;
 {
-  $Net::Stomp::Producer::VERSION = '1.3.1';
+  $Net::Stomp::Producer::VERSION = '1.001';
 }
 {
   $Net::Stomp::Producer::DIST = 'Net-Stomp-Producer';
 }
 use Moose;
 use namespace::autoclean;
-with 'Net::Stomp::MooseHelpers::CanConnect' => { -version => '1.1.0' };
-with 'Net::Stomp::MooseHelpers::ReconnectOnFailure';
+with 'Net::Stomp::MooseHelpers::CanConnect';
 use MooseX::Types::Moose qw(CodeRef HashRef);
 use Net::Stomp::Producer::Exceptions;
 use Class::Load 'load_class';
@@ -17,6 +16,35 @@ use Try::Tiny;
 # ABSTRACT: helper object to send messages via Net::Stomp
 
 
+# we automatically send the C<connect> frame
+around _build_connection => sub {
+    my ($orig,$self,@etc) = @_;
+    my $conn = $self->$orig(@etc);
+    $self->_connect($conn);
+    return $conn;
+};
+
+sub _connect {
+    my ($self,$connection) = @_;
+
+    try {
+        my $server = $self->current_server;
+        my %headers = (
+            %{$self->connect_headers},
+            %{$server->{connect_headers} || {}},
+        );
+        $connection->connect(\%headers);
+    } catch {
+        Net::Stomp::MooseHelpers::Exceptions::Stomp->throw({
+            stomp_error => $_
+        });
+    };
+}
+
+
+sub connect { warn "No-op, Net::Stomp::Producer connects on its own" }
+
+
 has serializer => (
     isa => CodeRef,
     is => 'rw',
@@ -60,7 +88,7 @@ sub send {
     my %actual_headers=(
         %{$self->default_headers},
         %$headers,
-        #'content-length' => length($body),
+        'content-length' => length($body),
         body => $body,
     );
 
@@ -71,9 +99,7 @@ sub send {
             unless m{^/};
     }
 
-    $self->reconnect_on_failure(
-        sub{ $_[0]->connection->send($_[1]) },
-        \%actual_headers);
+    $self->connection->send(\%actual_headers);
 
     return;
 }
@@ -99,7 +125,7 @@ sub make_transformer {
 }
 
 
-sub transform {
+sub transform_and_send {
     my ($self,$transformer,@input) = @_;
 
     $transformer=$self->make_transformer($transformer);
@@ -113,8 +139,6 @@ sub transform {
 
     my $vmethod = try { $transformer->can('validate') };
 
-    my @ret;
-
     while (my ($headers, $body) = splice @messages, 0, 2) {
         if ($vmethod) {
             my $exception;
@@ -130,34 +154,12 @@ sub transform {
                 });
             }
         }
-        push @ret,$headers,$body;
-    }
-
-    return @ret;
-}
-
-
-sub send_many {
-    my ($self,@messages) = @_;
-
-    while (my ($headers, $body) = splice @messages, 0, 2) {
         $self->send(undef,$headers,$body);
     }
 
     return;
 }
 
-
-sub transform_and_send {
-    my ($self,$transformer,@input) = @_;
-
-    my @messages = $self->transform($transformer,@input);
-
-    $self->send_many(@messages);
-
-    return;
-}
-
 __PACKAGE__->meta->make_immutable;
 
 
@@ -174,7 +176,7 @@ Net::Stomp::Producer - helper object to send messages via Net::Stomp
 
 =head1 VERSION
 
-version 1.3.1
+version 1.001
 
 =head1 SYNOPSIS
 
@@ -313,6 +315,12 @@ L</make_transformer> instantiates a transformer class.
 
 =head1 METHODS
 
+=head2 C<connect>
+
+Since the connection is set up automatically, this method (usually
+provided by L<Net::Stomp::MooseHelpers::CanConnect>) is overridden to
+be a no-op and warn. Don't call it.
+
 =head2 C<send>
 
   $p->send($destination,\%headers,$body);
@@ -337,9 +345,9 @@ C<new> method, it's invoked with the value of L</transformer_args> to
 obtain an object that is then returned. If the class does not have a
 C<new>, the class name is returned.
 
-=head2 C<transform>
+=head2 C<transform_and_send>
 
-  my (@headers_and_bodies) = $p->transform($transformer,@data);
+  $p->transform_and_send($transformer,@data);
 
 Uses L</make_transformer> to (optionally) instantiate a transformer
 object, then tries to call C<transform> on it. If there is no such
@@ -350,10 +358,11 @@ The transformer is expected to return a list of (header,body) pairs
 (that is, a list with an even number of elements; I<not> a list of
 arrayrefs!).
 
-Each message in the returned list is optionally validated, then returned.
+Each message in the returned list is optionally validated, then sent
+(via the L</send> method).
 
 The optional validation happens if the transformer C<<
-->can('validate') >>. If it can, that method is called like:
+->can('validate') >>. IF it can, that method is called like:
 
   $transformer->validate($header,$body_ref);
 
@@ -364,48 +373,9 @@ C<validate> method returns false without throwing any exception,
 L<Net::Stomp::Producer::Exceptions::Invalid> will still be throw, but
 the C<previous_exception> slot will be undef.
 
-It's not an error for the transformer to return an empty list: it just
-means that nothing will be returned.
-
-=head2 C<send_many>
-
-  $p->send_many(@headers_and_bodies);
-
-Given a list of (header,body) pairs (that is, a list with an even
-number of elements; I<not> a list of arrayrefs!), it will send each
-pair as a message. Useful in combination with L</transform>.
-
-It's not an error for the list to beempty: it just means that nothing
-will be sent.
-
-=head2 C<transform_and_send>
-
-  $p->transform_and_send($transformer,@data);
-
-Equivalent to:
-
-  $p->send_many($p->transform($transformer,@data));
-
-which is similar to:
-
-  my ($header,$body) = $p->transform($transformer,@data);
-  $p->send(undef,$header,$body);
-
-but it works also when the transformer returns more than one pair.
-
 It's not an error for the transformer to return an empty list: it just
 means that nothing will be sent.
 
-I<< Why would I ever want to use L</transform> and L</send_many> separately? >>
-
-Let's say you are in a transaction, and you want to fail if the
-messages cannot be prepared, but not fail if the prepared messages
-cannot be sent. In this case, you call L</transform> inside the
-transaction, and L</send_many> outside of it.
-
-But yes, in most cases you should really just call
-C<transform_and_send>.
-
 =head1 EXAMPLES
 
 You can find examples of use in the tests, or at
